require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Artifact
      # Attributes of the creation artifact presentation setting.
      class ArtifactSetPresentationAttributes < UU::OS::REST::DTO

        # @see Artifact#set_presentation_attributes
        attr_accessor :layout_artifact_uri

        # @see Artifact#set_presentation_attributes
        attr_accessor :artifact_width

        # @see Artifact#set_presentation_attributes
        attr_accessor :header_display_mode

        # @see Artifact#set_presentation_attributes
        attr_accessor :control_bar_display_mode

        # @see Artifact#set_presentation_attributes
        attr_accessor :comment_display_mode

        # @deprecated Use {#artifact_display_mode} instead.
        attr_accessor :context_menu_display_mode

        # @see Artifact#set_presentation_attributes
        attr_accessor :artifact_display_mode

        # @see Artifact#set_presentation_attributes
        attr_accessor :visual_style

        # @see Artifact#set_presentation_attributes
        attr_accessor :navigation_area_display_mode

        def layout_artifact_uri
          attributes[:layoutArtifactUri]
        end

        def layout_artifact_uri=(val)
          if val
            if (val.kind_of?String) && (val.strip.empty?)
              # if is value empty string use NULL_URI, inspired by NULL_URI on java api of UESURI
              uri = 'ues:[-1]:[-1]:'
            else
              uri = val
            end
            attributes[:layoutArtifactUri] = UU::OS::UESURI.new(uri)
          else
            attributes[:layoutArtifactUri] = nil
          end
        end

        def artifact_width
          attributes[:artifactWidth]
        end

        def  artifact_width=(val)
          attributes[:artifactWidth] = val
        end

        def header_display_mode
          attributes[:headerDisplayMode]
        end

        def header_display_mode=(val)
          attributes[:headerDisplayMode] = val
        end

        def control_bar_display_mode
          attributes[:controlBarDisplayMode]
        end

        def control_bar_display_mode=(val)
          attributes[:controlBarDisplayMode] = val
        end

        def comment_display_mode
          attributes[:commentDisplayMode]
        end

        def comment_display_mode=(val)
          attributes[:commentDisplayMode] = val
        end

        # @deprecated
        def context_menu_display_mode
          attributes[:contextMenuDisplayMode]
        end

        # @deprecated
        def context_menu_display_mode=(val)
          attributes[:contextMenuDisplayMode] = val
        end

        def artifact_display_mode
          attributes[:artifactDisplayMode]
        end

        def artifact_display_mode=(val)
          attributes[:artifactDisplayMode] = val
        end

        def visual_style
          attributes[:visualStyle]
        end

        def visual_style=(val)
          attributes[:visualStyle] = val
        end

        def navigation_area_display_mode
          attributes[:navigationAreaDisplayMode]
        end

        def navigation_area_display_mode=(val)
          attributes[:navigationAreaDisplayMode] = val
        end

      end
    end
  end
end
