require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS

    module UseCaseRealization
      # @deprecated Use {UU::OS::VisualUseCase::VisualUseCaseCreate} instead.
      class UseCaseRealizationCreate < UU::OS::REST::DTO

        # Name of the new use case realization. When null is set, default name from meta artifact is used if set, otherwise the create command
        # fails.
        attr_accessor :name

        # Code of the new use case realization. When null is set, the code is generated automatically using the system sequence. The code must be
        # unique in the given territory, otherwise the create command fails.
        attr_accessor :code

        # Description of the new use case realization. When null is set, default description from meta artifact is used if set, otherwise no
        # description is set on the new use case realization.
        attr_accessor :description

        # Security level. When null is set, security level is taken from the meta artifact default security level. If the meta artifact template
        # security level is higher than the user's security clearance, the create command fails.
        attr_accessor :security_level

        # UESURI of the use case realization's icon. When null is set, the role uses icon from meta artifact.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri

        # Path at which the controller will be deployed
        attr_accessor :controller_url_path

        # Classs to look for when executing this UCR
        attr_accessor :controller_class

        # Engine used for this UCR
        attr_accessor :controller_engine

        # UESURI of the competent role. When null is set, the executive role from authorization is used. If no role is authorized to create the
        # use case realization into specified container, the create command fails. If the selected role doesn't have connected the role interface
        # with the selected meta artifact, the create command fails. If the selected role doesn't belong to the same organizational unit as a new
        # use case realization or if it doesn't belong to one of superior organizational units, the create command fails.
        attr_accessor :competent_role_uri

        # UESURI of the meta artifact. Only a meta artifact with the template class of Use case realization (not its descendants) can be used. If
        # the rights does not permit to create a new use case realization from the meta artifact in the specified location, the create command
        # fails.
        attr_accessor :meta_artifact_uri

        # Options data for use case calling. Accepted format is JSON.
        attr_accessor :options
        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def controller_url_path
          attributes[:controllerUrlPath]
        end

        def controller_url_path=(val)
          attributes[:controllerUrlPath] = val
        end

        def controller_class
          attributes[:controllerClass]
        end

        def controller_class=(val)
          attributes[:controllerClass] = val
        end

        def controller_engine
          attributes[:controllerEngine]
        end

        def controller_engine=(val)
          attributes[:controllerEngine] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def options
          attributes[:options]
        end

        def options=(val)
          if val
            attributes[:options] = UU::OS::REST::BinaryValue.new(val)
          else
            attributes[:options] = nil
          end
        end

      end
    end
  end

end
